# EXPERIMENTAL modules

This folder contains experimental modules. These modules are not supported by Cognite.

They are used to test new features and ideas. They may be removed at any time or promoted to a stable module.
